<a id="{{ current_node.html_id }}" href="#{{ current_node.html_id }}">
    <h2 class="handle ml-2 mt-2">
      <label>{% if operator == "allOf" -%}All of{% elif operator == "anyOf" -%}Any of{% elif operator == "oneOf" -%}One of{% endif -%}</label>
    </h2>
</a>
{%- set tab_label = "Option" -%}
{%- if operator == "allOf" -%}
    {%- set tab_label = "Requirement" -%}
{%- endif -%}
{%- for node in current_node.array_items -%}
    <div class="card">
        <h3 class="ml-2 mt-2"><a id="{{ node.html_id }}" href="#{{ node.html_id }}">{{ node.definition_name or tab_label ~ " " ~ loop.index }}</a></h3>
        <div class="card-body">
            {{ content(node) }}
        </div>
    </div>
{%- endfor -%}