from enum import Enum


class SchemaKeyword(Enum):
    REQUIRED = "required"
    TITLE = "title"
    CONTAINS = "contains"
    DESCRIPTION = "description"
    EXAMPLES = "examples"
    ITEMS = "items"
    PREFIX_ITEMS = "prefixItems"
    UNIQUE_ITEMS = "uniqueItems"
    ADDITIONAL_ITEMS = "additionalItems"
    MAX_ITEMS = "maxItems"
    MIN_ITEMS = "minItems"
    MAX_LENGTH = "maxLength"
    MIN_LENGTH = "minLength"
    MULTIPLE_OF = "multipleOf"
    MINIMUM = "minimum"
    EXCLUSIVE_MINIMUM = "exclusiveMinimum"
    MAXIMUM = "maximum"
    EXCLUSIVE_MAXIMUM = "exclusiveMaximum"
    PATTERN = "pattern"
    CONST = "const"
    ENUM = "enum"
    META_ENUM = "meta:enum"
    ELSE = "else"
    THEN = "then"
    IF = "if"
    NOT = "not"
    ONE_OF = "oneOf"
    ANY_OF = "anyOf"
    ALL_OF = "allOf"
    PROPERTIES = "properties"
    PATTERN_PROPERTIES = "patternProperties"
    ADDITIONAL_PROPERTIES = "additionalProperties"
    FORMAT = "format"
    TYPE = "type"
